==> aws-cdk-scala-cloudtrail_2.12-0.2.0-sources.jar: io/burkard/cdk/services/cloudtrail/TrailProps.scala <==
package io.burkard.cdk.services.cloudtrail

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object TrailProps {

  def apply(
    enableFileValidation: Option[Boolean] = None,
    cloudWatchLogGroup: Option[software.amazon.awscdk.services.logs.ILogGroup] = None,
    snsTopic: Option[software.amazon.awscdk.services.sns.ITopic] = None,
    bucket: Option[software.amazon.awscdk.services.s3.IBucket] = None,
    encryptionKey: Option[software.amazon.awscdk.services.kms.IKey] = None,
    s3KeyPrefix: Option[String] = None,
    includeGlobalServiceEvents: Option[Boolean] = None,
    cloudWatchLogsRetention: Option[software.amazon.awscdk.services.logs.RetentionDays] = None,
    isMultiRegionTrail: Option[Boolean] = None,
    trailName: Option[String] = None,
    sendToCloudWatchLogs: Option[Boolean] = None,
    managementEvents: Option[software.amazon.awscdk.services.cloudtrail.ReadWriteType] = None
  ): software.amazon.awscdk.services.cloudtrail.TrailProps =
    (new software.amazon.awscdk.services.cloudtrail.TrailProps.Builder)
      .enableFileValidation(enableFileValidation.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .cloudWatchLogGroup(cloudWatchLogGroup.orNull)
      .snsTopic(snsTopic.orNull)
      .bucket(bucket.orNull)
      .encryptionKey(encryptionKey.orNull)
      .s3KeyPrefix(s3KeyPrefix.orNull)
      .includeGlobalServiceEvents(includeGlobalServiceEvents.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .cloudWatchLogsRetention(cloudWatchLogsRetention.orNull)
      .isMultiRegionTrail(isMultiRegionTrail.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .trailName(trailName.orNull)
      .sendToCloudWatchLogs(sendToCloudWatchLogs.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .managementEvents(managementEvents.orNull)
      .build()
}

==> aws-cdk-scala-cloudtrail_2.13-0.1.4-sources.jar: io/burkard/cdk/services/cloudtrail/TrailProps.scala <==
package io.burkard.cdk.services.cloudtrail

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object TrailProps {

  def apply(
    kmsKey: Option[software.amazon.awscdk.services.kms.IKey] = None,
    enableFileValidation: Option[Boolean] = None,
    cloudWatchLogGroup: Option[software.amazon.awscdk.services.logs.ILogGroup] = None,
    snsTopic: Option[software.amazon.awscdk.services.sns.ITopic] = None,
    bucket: Option[software.amazon.awscdk.services.s3.IBucket] = None,
    encryptionKey: Option[software.amazon.awscdk.services.kms.IKey] = None,
    s3KeyPrefix: Option[String] = None,
    includeGlobalServiceEvents: Option[Boolean] = None,
    cloudWatchLogsRetention: Option[software.amazon.awscdk.services.logs.RetentionDays] = None,
    isMultiRegionTrail: Option[Boolean] = None,
    trailName: Option[String] = None,
    sendToCloudWatchLogs: Option[Boolean] = None,
    managementEvents: Option[software.amazon.awscdk.services.cloudtrail.ReadWriteType] = None
  ): software.amazon.awscdk.services.cloudtrail.TrailProps =
    (new software.amazon.awscdk.services.cloudtrail.TrailProps.Builder)
      .kmsKey(kmsKey.orNull)
      .enableFileValidation(enableFileValidation.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .cloudWatchLogGroup(cloudWatchLogGroup.orNull)
      .snsTopic(snsTopic.orNull)
      .bucket(bucket.orNull)
      .encryptionKey(encryptionKey.orNull)
      .s3KeyPrefix(s3KeyPrefix.orNull)
      .includeGlobalServiceEvents(includeGlobalServiceEvents.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .cloudWatchLogsRetention(cloudWatchLogsRetention.orNull)
      .isMultiRegionTrail(isMultiRegionTrail.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .trailName(trailName.orNull)
      .sendToCloudWatchLogs(sendToCloudWatchLogs.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .managementEvents(managementEvents.orNull)
      .build()
}
